;##################################################################
;
;   P H O E N I X         F O R        T I - 8 3
;
;   Programmed by Patrick Davidson (pad@calc.org)
;        
;   This program is in the public domain.  There is no warranty.
;
;   This file was last updated October 1, 2000.
;
;##################################################################     

	.nolist
	#include "ion.inc"
	#include "keys.inc"
	.list
#ifdef TI83P
	.org	progstart-2
	.db	$BB,$6D
#else
	.org	progstart
#endif
	ret
	jr	nc,start

        .db     "Phoenix 0.50",0



GFX_AREA    = plotsscreen



;############## Include variable and data structure definitions
        
#include "phoenixz.h"

;############## Initialization

start:
        ld      (_label-2),sp

	im 1

	di

        ;ld      a,(INT_STATE)
        ;or      a
        ;jp      nz,interrupt_installed

        ld      de,saferam1+473                ; Save data after GRAPH_MEM
        ld      hl,plotsscreen+768
        ld      bc,256
        ldir


#ifdef TI83
        ld      hl,timer_interrupt
        ld      de,$8282
        ld      bc,timer_interrupt_end-timer_interrupt
        ldir

        ld      a,$83
        ld      i,a

        ld      hl,$8300
        ld      (hl),$82
        ld      bc,256
        call    OTH_FILL
#endif

#ifdef TI83P
        ld      hl,timer_interrupt
        ld      de,$9898
        ld      bc,timer_interrupt_end-timer_interrupt
        ldir

        ld      a,$99
        ld      i,a

        ld      hl,$9900
        ld      (hl),$98
        ld      bc,256
        call    OTH_FILL
#endif

        im      2
	ei

        ld      (iy+13),0

        call    restore_game
  
;############## Title screen

redraw_title:
        bcall(_clrlcdf)
        ld      hl,title_main

show_title:
        call    display_hl_msgs
        
title_loop:
        bcall(_getcsc)
        cp      G_2
        jr      z,show_contact
        cp      G_3
        jr      z,show_instructions
        cp      G_1
        jp      z,start_new_game
        cp      G_CLEAR
        jr      z,game_exit
        cp      G_ALPHA
        jr      z,show_highs
        cp      G_DEL
        jr      nz,title_loop

game_exit:
	di
        im      1 
        call    restore_memory
OTH_EXIT:
        ld      a,05h		; set x inc mode
        call    DISP_DELAY	;
        out     (16),a		;
        ld      sp,0
_label:
	ei
        bcall(_clrlcdf)
        ret


show_highs:
        call    no_high_score
        jr      redraw_title

show_contact:
        ld      hl,title_contact
        jr      show_title

show_instructions:
        ld      hl,title_instructions
        jr      show_title

;############## Title screen messages

title_main:
        .db     "  Phoenix 0.50",0
        .db     0
        .db     "  Programmed by",0
        .db     "Patrick Davidson",0
        .db     0
        .db     " 1 - Start Game",0
        .db     "2 - Contact Info",0
        .db     "3 - Instructions",0
        .db     -1

title_instructions:
        .db     "Arrows Move Ship",0
        .db     "#s Select Weapon",0
        .db     "2nd Fires Weapon",0
        .db     "MODE Save & Exit",0
        .db     -1

title_contact:
        .db     "E-Mail:         ",0
        .db     "    pad@calc.org",0
        .db     "World Wide Web: ",0
        .db     "   pad.calc.org ",0
        .db     -1

;############## Initialize a new game

start_new_game:
        call    initialize_game

pre_main_loop:
        ld      hl,-6
        add     hl,sp
        ld      (collision_done+1),hl
        
;############## Game main loop
        
main_loop:
        ld      hl,(game_timer)
        inc     hl
        ld      (game_timer),hl

        bit     0,l
        jr      z,time_elapsed
        ld      hl,(time_score)
        ld      a,h
        or      l
        jr      z,time_elapsed
        dec     hl
        ld      (time_score),hl
time_elapsed:

        call    clear_buffer           ; Prepare main display buffer

        call    do_player              ; Move and draw player
        call    do_companion           ; Move and draw companion ship

        call    enemies                ; Move and draw enemies

        call    player_bullets         ; Move and draw player bullets

        call    enemy_bullets          ; Move and draw enemy bullets
        call    hit_player             ; Collisions involving player

        call    synchronize            ; Wait for next 1/30 second cycle
        call    display_screen         ; Copy display buffer to video memory

        call    hit_enemies            ; Collisions btw. bullets & enemies

        call    handle_input           ; Process control keys
        ld      a,(enemies_left)
        or      a
        call    z,load_level
        jr      main_loop

;############## TI-82 library

restore_memory:
        ld      hl,saferam1+473                ; Restore data after GRAPH_MEM
        ld      de,plotsscreen+768
        ld      bc,256
        ldir
        ret

DISP_DELAY:
        push    ix
        pop     ix
        ret

OTH_CLEAR:
        ld      (hl),0
OTH_FILL:
        ld      d,h
        ld      e,l
        inc     de
        ldir
        ret

OTH_ARROW:
        ld      a,%00111111
        out     (1),a
        push    ix
        pop     ix
        in      a,(1)
        or      %00001111
        ld      b,a
        ld      a,%01111110
        out     (1),a
        push    ix
        pop     ix
        in      a,(1)
        and     b
        ret

        .end
        
;############## Include remainder of game files
        
#include "lib.asm"
#include "new82.asm"
#include "disp82.asm"
#include "drwspr.asm"
#include "player82.asm"
#include "shoot.asm"
#include "bullets.asm"
#include "enemies.asm"
#include "init.asm"
#include "enemyhit.asm"
#include "collide.asm"
#include "ebullets.asm"
#include "hityou.asm"
#include "shop82.asm"
#include "helper.asm"
#include "eshoot.asm"
#include "score82.asm"
#include "images.asm"
#include "data.asm"
